# Generated by Django 2.2.16 on 2020-10-29 16:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("django_video_encoder", "0003_auto_20201029_1613"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="format",
            name="format",
        ),
    ]



from django.apps import AppConfig


class DjangoVideoEncoderConfig(AppConfig):
    name = "django_video_encoder"
    verbose_name = "Django Video Encoder"

    def ready(self):
        # Add System checks
        from .checks import check__formats  # NOQA



from django.conf import settings
from django.core import checks

from django_video_encoder.models import Format


@checks.register
def check__formats(app_configs, **kwargs):
    if not hasattr(settings, "DJANGO_VIDEO_ENCODER_FORMATS"):
        return [checks.Error("No DJANGO_VIDEO_ENCODER_FORMATS defined in settings")]
    errors = []
    encoder_list = [format for format, __ in Format.VIDEO_CODEC_CHOICES]
    for format in settings.DJANGO_VIDEO_ENCODER_FORMATS.values():
        if "video_codec" not in format:
            errors.append(
                checks.Error(f"Format dict {format} has no defined `video_codec`")
            )
            continue
        if not format["video_codec"] in encoder_list:
            errors.append(
                checks.Error(
                    f"Requested codec {format['video_codec']} is not defined in "
                    f"{encoder_list}"
                )
            )
    return errors



# Generated by Django 2.2.16 on 2020-10-29 16:13

from django.db import migrations, models
from django.db.models import F


def update_formats(apps, schema_editor):
    Format = apps.get_model("django_video_encoder", "Format")
    Format.objects.update(format_label=F("format"))


class Migration(migrations.Migration):

    dependencies = [
        ("django_video_encoder", "0002_auto_20201022_1647"),
    ]

    operations = [
        migrations.AddField(
            model_name="format",
            name="format_label",
            field=models.CharField(default="", editable=False, max_length=80),
        ),
        migrations.AddField(
            model_name="format",
            name="video_codec",
            field=models.CharField(
                choices=[
                    ("h264", "h264"),
                    ("hevc", "hevc"),
                    ("jp2", "jp2"),
                    ("mpeg4", "mpeg4"),
                    ("theora", "theora"),
                    ("vp6", "vp6"),
                    ("vp8", "vp8"),
                    ("vp9", "vp9"),
                    ("wmv", "wmv"),
                ],
                default="h264",
                max_length=50,
            ),
        ),
        migrations.RunPython(update_formats, reverse_code=migrations.RunPython.noop),
    ]
